import setuptools

setuptools.setup(
	name='KEGE22',
	version='1.0',
	author='ShakeDLL',
	author_email='repetskys@yandex.ru',
	description='ege22',
	packages=['KEGE22'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)